@@ -122,8 +122,13 @@ def download_layer(layer, url,  dest_dir, username=None, password=None):
                     (layer['name'], download_link))
             log.error(msg)
             raise RuntimeError(msg)
-        # Figure out the filename based on the 'content-disposition' header.
-        filename = r.headers['content-disposition'].split('filename=')[1]
+
+        filename = layer['name']
+
+        # Strip out the 'geonode:' if it exists
+        if ':' in filename:
+            filename = layer['name'].split(':')[1]
+        
         layer_filename = os.path.join(dest_dir, filename)
         with open(layer_filename, 'wb') as layer_file:
             layer_file.write(content)
@@ -179,9 +184,13 @@ def download_layer(layer, url,  dest_dir, username=None, password=None):
 
     # Download the associated style
     style_data = get_style(layer, url, username, password)
+
+    xml_style_data = minidom.parseString(style_data)
+    pretty_style_data = xml_style_data.toprettyxml().encode('utf-8')
+
     style_filename = base_filename + '.sld'
     with open(style_filename, 'wb') as style_file:
-        style_file.write(style_data)
+        style_file.write(pretty_style_data)
         log.debug('Saved style from "%s" as "%s"' % (layer['name'], style_filename))
 
 
@@ -242,7 +251,11 @@ def get_data(argv=None):
 
 
     all_layers = data['rows']
-    next_list = data['next']
+
+    if 'next' in data:
+        next_list = data['next']
+    else:
+        next_list = None
 
     while(next_list is not None):
         new_data = get_layer_list(url, endpoint=next_list)
@@ -257,7 +270,6 @@ def get_data(argv=None):
     # Since the search API may return paginated results, repeast the process to fetch all layers.
 
     layers = all_layers
-    print len(layers)
     if limit is not None:
         if limit < len(all_layers):
             layers = all_layers[:limit]
